==> ozacc-mail-1.0-src.tar.gz: ozacc-mail-1.0/src/test/com/ozacc/mail/xml/impl/XMLBuilderImplTest.java <==
package com.ozacc.mail.xml.impl;

import junit.framework.TestCase;

import org.jdom.Document;
import org.jdom.input.DOMBuilder;
import org.jdom.output.XMLOutputter;

import com.ozacc.mail.Mail;
import com.ozacc.mail.xml.XMLBuilder;

/**
 * 
 * @author Tomohiro Otsuka
 * @version $Id: XMLBuilderImplTest.java,v 1.2 2004/09/10 07:36:14 otsuka Exp $
 */
public class XMLBuilderImplTest extends TestCase {

	private XMLBuilder builder;

	/*
	 * @see TestCase#setUp()
	 */
	protected void setUp() throws Exception {
		super.setUp();

		builder = new XMLBuilderImpl();
	}

	public final void testCreateDocument() throws Exception {
		Mail mail = getMailForTest();

		org.w3c.dom.Document doc = builder.buildDocument(mail);

		DOMBuilder builder = new DOMBuilder();
		Document jdomDoc = builder.build(doc);

		System.out.println(jdomDoc);

		XMLOutputter outputter = new XMLOutputter();
		String document = outputter.outputString(jdomDoc);
		System.out.println(document);
	}

	/*
	 * Class under test for void saveDocument(Mail, File)
	 */
	/*public final void testSaveDocumentMailFile() throws Exception {
	 try {
	 Mail mail = getMailForTest();

	 String filePath = "target/test/data/mail-jdk.xml";
	 File file = new File(filePath);
	 file.getParentFile().mkdirs();

	 builder.saveDocument(mail, file);
	 } catch (Throwable t) {
	 t.printStackTrace();
	 }
	 }*/

	/**
	 * @return 
	 */
	private Mail getMailForTest() {
		String from = "from@example.com";
		String fromName = "п";
		String to = "info@example.com";
		String subject = "̾";
		String text = "ƥ";

		Mail mail = new Mail();
		mail.setFrom(from, fromName);
		mail.addTo(to);
		mail.setSubject(subject);
		mail.setText(text);
		return mail;
	}

}

==> ozacc-mail-1.0.1-src.tar.gz: ozacc-mail-1.0.1/src/test/com/ozacc/mail/xml/impl/XMLBuilderImplTest.java <==
package com.ozacc.mail.xml.impl;

import java.io.File;

import junit.framework.TestCase;

import org.jdom.Document;
import org.jdom.input.DOMBuilder;
import org.jdom.output.XMLOutputter;

import com.ozacc.mail.Mail;
import com.ozacc.mail.xml.XMLBuilder;

/**
 * 
 * @author Tomohiro Otsuka
 * @version $Id: XMLBuilderImplTest.java,v 1.3 2004/09/13 07:13:53 otsuka Exp $
 */
public class XMLBuilderImplTest extends TestCase {

	private XMLBuilder builder;

	/*
	 * @see TestCase#setUp()
	 */
	protected void setUp() throws Exception {
		super.setUp();

		builder = new XMLBuilderImpl();
	}

	public final void testCreateDocument() throws Exception {
		Mail mail = getMailForTest();

		org.w3c.dom.Document doc = builder.buildDocument(mail);

		DOMBuilder builder = new DOMBuilder();
		Document jdomDoc = builder.build(doc);

		System.out.println(jdomDoc);

		XMLOutputter outputter = new XMLOutputter();
		String document = outputter.outputString(jdomDoc);
		System.out.println(document);
	}

	/*
	 * Class under test for void saveDocument(Mail, File)
	 */
	public final void testSaveDocumentMailFile() throws Exception {
		Mail mail = getMailForTest();

		String filePath = "target/test/data/mail-jdk.xml";
		File file = new File(filePath);
		file.getParentFile().mkdirs();

		builder.saveDocument(mail, file);
	}

	/**
	 * @return 
	 */
	private Mail getMailForTest() {
		String from = "from@example.com";
		String fromName = "п";
		String to = "info@example.com";
		String subject = "̾";
		String text = "ƥ";

		Mail mail = new Mail();
		mail.setFrom(from, fromName);
		mail.addTo(to);
		mail.setSubject(subject);
		mail.setText(text);
		return mail;
	}

}
